Event

Struct Event 

pub struct Event<D> {
    pub data: D,
    /* private fields */
}
Typed event with deserialized data.

Event wraps a raw crate::Event and provides typed access to the deserialized event data. It implements Deref to provide access to the underlying event fields (id, timestamp, version, metadata, etc.).

Type Parameters

  • D: The event data type (e.g., AccountOpened)

Example

use evento::metadata::Event;

#[evento::handler]
async fn handle_deposit(
    event: Event<MoneyDeposited>,
    view: &mut AccountView,
) -> anyhow::Result<()> {
    // Access typed data
    println!("Amount: {}", event.data.amount);

    // Access metadata via Deref
    if let Ok(user) = event.metadata.requested_by() {
        println!("By user: {}", user);
    }

    // Access underlying event fields via Deref
    println!("Event ID: {}", event.id);
    println!("Version: {}", event.version);

    Ok(())
}

Fields

data: D

The typed event data