EventData

Struct EventData 

pub struct EventData<D, M = bool> {
    pub data: D,
    pub metadata: M,
    /* private fields */
}
Typed event with deserialized data and metadata.

EventData wraps a raw Event and provides typed access to the deserialized event data and metadata. It implements Deref to provide access to the underlying event fields (id, timestamp, version, etc.).

Type Parameters

  • D: The event data type (e.g., AccountOpened)
  • M: The metadata type (defaults to bool for no metadata)

Example

use evento::metadata::Event;

#[evento::handler]
async fn handle_deposit<E: Executor>(
    event: Event<MoneyDeposited>,
    action: Action<'_, AccountView, E>,
) -> anyhow::Result<()> {
    // Access typed data
    println!("Amount: {}", event.data.amount);

    // Access metadata
    if let Ok(user) = event.metadata.user() {
        println!("By user: {}", user);
    }

    // Access underlying event fields via Deref
    println!("Event ID: {}", event.id);
    println!("Version: {}", event.version);

    Ok(())
}

Fields

data: D

The typed event data

metadata: M

The typed event metadata