Context

Struct Context 

pub struct Context<'a, E: Executor> {
    pub executor: &'a E,
    /* private fields */
}
Handler context providing access to executor and shared data.

Context wraps an RwContext for type-safe data storage and provides access to the executor for database operations.

Example

#[evento::handler]
async fn my_handler<E: Executor>(
    event: Event<MyEventData>,
    action: Action<'_, MyView, E>,
) -> anyhow::Result<()> {
    if let Action::Handle(ctx) = action {
        // Access shared data
        let config: Data<AppConfig> = ctx.extract();

        // Use executor for queries
        let events = ctx.executor.read(...).await?;
    }
    Ok(())
}

Fields

executor: &'a E

Reference to the executor for database operations

Methods from Deref<Target = RwContext>

pub fn insert<T: Send + Sync + 'static>(&self, val: T) -> Option<T>

Insert an item into the map.

If an item of this type was already stored, it will be replaced and returned.

pub fn contains<T: 'static>(&self) -> bool

Check if map contains an item of a given type.

pub fn extract<T: Clone + 'static>(&self) -> T

Get a clone of an item of a given type, panics if not found.

pub fn get<T: Clone + 'static>(&self) -> Option<T>

Get a clone of an item of a given type.

pub fn remove<T: Send + Sync + 'static>(&self) -> Option<T>

Remove an item from the map of a given type.

If an item of this type was already stored, it will be returned.

pub fn clear(&self)

Clear the RwContext of all inserted extensions.

pub fn extend(&self, other: Context)

Extends self with the items from another Context.